@@ -14,6 +14,7 @@ from .PopoverHeader import PopoverHeader
 from .Progress import Progress
 from .Spinner import Spinner
 from .Table import Table
+from .Toast import Toast
 from .Tooltip import Tooltip
 from .Card import Card
 from .CardBody import CardBody
@@ -76,6 +77,7 @@ __all__ = [
     "Progress",
     "Spinner",
     "Table",
+    "Toast",
     "Tooltip",
     "Card",
     "CardBody",
